@@ -1,6 +1,6 @@
-#!D:\bld\gdal-split_1571853568198\_h_env\python.exe
+#!D:\bld\gdal-split_1578951822587\_h_env\python.exe
 ###############################################################################
-# $Id: gdal_merge.py c5384abb7792fb874126f6430f39b5cbf2d95084 2018-05-24 14:13:29 -0400 Lucas de la Garza $
+# $Id: gdal_merge.py 7f3d00d9d3fa1b9317a696e0f22a378820d89d6b 2019-07-12 07:47:26 -0700 ajnisbet $
 #
 # Project:  InSAR Peppers
 # Purpose:  Module to extract data from many rasters into one output.
@@ -82,14 +82,14 @@ def GetOutputDriversFor(filename):
 
 def GetOutputDriverFor(filename):
     drv_list = GetOutputDriversFor(filename)
+    ext = GetExtension(filename)
     if not drv_list:
-        ext = GetExtension(filename)
         if not ext:
             return 'GTiff'
         else:
             raise Exception("Cannot guess driver for %s" % filename)
     elif len(drv_list) > 1:
-        print("Several drivers matching %s extension. Using %s" % (ext, drv_list[0]))
+        print("Several drivers matching %s extension. Using %s" % (ext if ext else '', drv_list[0]))
     return drv_list[0]
 
 
